/*
Make sure the following are on your classpath:

* Xerces or JAXP (included with Java 1.5)
* mail.jar ( http://java.sun.com/products/javamail )
* activation.jar ( http://java.sun.com/products/javabeans/glasgow/jaf.html )
* Apache SOAP ( http://ws.apache.org/soap )
* WSDL4J ( http://sourceforge.net/projects/wsdl4j )
* jurst ( http://www.nsftools.com/tools/jurst.htm )

For a WSDL dump, run:
java InteropEchoString

To test the echo string service, run:
java InteropEchoString This is my string

For more information about this web service, see:
http://mssoapinterop.org

A good source for other similar testing sites is at:
http://www.whitemesa.com/interop.htm
*/
import com.nsftools.jurst.SoapHelper;

public class InteropEchoString {

	public static void main(String[] args) {
		try {
			String wsdlURI = "http://mssoapinterop.org/stkV3/Interop.wsdl";
			SoapHelper sh = new SoapHelper(wsdlURI);
			
			// turn debugging on, if you want to see what's going on
			//sh.setDebugOut(System.err);
			
			if (args.length == 0) {
				System.out.println("WSDL URI = " + wsdlURI + "\n");
				System.out.println("METHOD LIST");
				System.out.println(sh.dumpMethodList());
			} else {
				StringBuffer sb = new StringBuffer();
				for (int i = 0; i < args.length; i++) {
					sb.append(args[i] + " ");
				}
				String str = sb.toString().trim();
				
				/*
				 * the is an example of a web service that returns an "untyped"
				 * response, where the information in the response envelope
				 * looks like this:
				 * ...<Result>This is the result</Result>...
				 * instead of:
				 * ...<Result xsi:type="xsd:string">This is the result</Result>...
				 * 
				 * Because of this, our SOAP client won't know how to "deserialize" 
				 * the response, so you'll get a SoapException like:
				 * "No Deserializer found to deserialize a 'Result'"
				 * 
				 * The solution is to explicitly tell the underlying code 
				 * what data type the <result> element is, so it can be
				 * returned as a proper Java class. In this case, there's
				 * a single response node called "Result" (which is obvious if
				 * we look at the WSDL file, or if we simply call the method
				 * once with debugging turned on using setDebugOut), and we'll 
				 * declare it as a String like this:
				 */ 
				sh.addReturnDatatype("Result", 
						new org.apache.soap.encoding.soapenc.StringDeserializer());
				
				// now that we know how to interpret the response, we can call the method
				String result = (String)sh.callSimpleMethod("echoString", str);
				if (sh.isFault())
					System.out.println("A fault was returned echoing '" + str + "': " + result);
				else
					System.out.println("Echo of '" + str + "' is '" + result + "'");
			}
		} catch (Exception e) {
			e.printStackTrace();
		}
		
	}

}
