/*
Make sure the following are on your classpath:

* Xerces or JAXP (included with Java 1.5)
* mail.jar ( http://java.sun.com/products/javamail )
* activation.jar ( http://java.sun.com/products/javabeans/glasgow/jaf.html )
* Apache SOAP ( http://ws.apache.org/soap )
* WSDL4J ( http://sourceforge.net/projects/wsdl4j )
* jurst ( http://www.nsftools.com/tools/jurst.htm )

For a WSDL dump, run:
java WeatherReportTestComplex

To look up weather for an airport, run:
java WeatherReportTestComplex KATL

Make sure you use the 4-letter ICAO code for your airport, not the 3-letter IATA code:
http://www.airport-technology.com/icao-codes/

More information about this web service at:
http://www.capescience.com/webservices/airportweather/index.shtml
*/
import com.nsftools.jurst.*;

public class WeatherReportTestComplex {

	public static void main(String[] args) {
		try {
			String wsdlURI = "http://live.capescience.com/wsdl/AirportWeather.wsdl";
			SoapHelper sh = new SoapHelper(wsdlURI);
			
			if (args.length == 0) {
				System.out.println("WSDL URI = " + wsdlURI + "\n");
				System.out.println("METHOD LIST");
				System.out.println(sh.dumpMethodList());
			} else {
				// the WeatherReport data type that is returned is a complex
				// data type modeled by the WeatherSummary class
				sh.addComplexDatatype("WeatherSummary", WeatherSummary.class);
				String airport = args[0];
				Object obj = sh.callSimpleMethod("getSummary", airport);
				
				if (sh.isFault()) {
					System.out.println("A fault was returned looking up weather for " + 
							airport + ": " + obj);
				} else {
					WeatherSummary report = (WeatherSummary)obj;
					System.out.println("The weather report for " + 
							airport + " is:\n" + report);
					//System.out.println("\nThe full response was:\n" + sh.getLastXmlResponse());
				}
			}
		} catch (Exception e) {
			e.printStackTrace();
		}
		
	}
	
}

