/*
Make sure the following are on your classpath:

* Xerces or JAXP (included with Java 1.5)
* mail.jar ( http://java.sun.com/products/javamail )
* activation.jar ( http://java.sun.com/products/javabeans/glasgow/jaf.html )
* Apache SOAP ( http://ws.apache.org/soap )
* WSDL4J ( http://sourceforge.net/projects/wsdl4j )
* jurst ( http://www.nsftools.com/tools/jurst.htm )

For a WSDL dump, run:
java WeatherReportTestXml

To look up weather for an airport, run:
java WeatherReportTestXml ATL

More information about this web service at:
http://www.capescience.com/webservices/globalweather/index.shtml
*/
import com.nsftools.jurst.*;
import org.w3c.dom.*;

public class WeatherReportTestXml {

	public static void main(String[] args) {
		try {
			String wsdlURI = "http://live.capescience.com/wsdl/GlobalWeather.wsdl";
			SoapHelper sh = new SoapHelper(wsdlURI);
			
			if (args.length == 0) {
				System.out.println("WSDL URI = " + wsdlURI + "\n");
				System.out.println("METHOD LIST");
				System.out.println(sh.dumpMethodList());
			} else {
				// the WeatherReport data type that is returned is a complex
				// data type with a lot of nested complex data types within it.
				// Instead of trying to model the type with a class and read it
				// as a Bean, we'll just accept it as a DOM Node (by using
				// XmlNodeDeserializer) and parse it when we get it.
				sh.addReturnDatatype("WeatherReport", new XmlNodeDeserializer());
				String airport = args[0];
				Object obj = sh.callSimpleMethod("getWeatherReport", airport);
				
				if (sh.isFault()) {
					System.out.println("A fault was returned looking up weather for " + 
							airport + ": " + obj);
				} else {
					Node report = (Node)obj;
					System.out.println("The weather report (in XML) for " + 
							airport + " is " + printXmlResponse(report, ""));
					//System.out.println("\nThe full response was:\n" + sh.getLastXmlResponse());
				}
			}
		} catch (Exception e) {
			e.printStackTrace();
		}
		

	}
	
	public static String printXmlResponse (Node node, String indent) {
		StringBuffer sb = new StringBuffer();
		int type = node.getNodeType();
		
		switch (type) {
			case Node.ELEMENT_NODE: {
				sb.append("\n" + indent + "<" + node.getNodeName() + ">");
				NodeList children = node.getChildNodes();
				if (children != null) {
					for (int i = 0; i < children.getLength(); i++)
						sb.append(printXmlResponse(children.item(i), indent + "    "));
				}
				sb.append("</" + node.getNodeName() + ">");
				break;
		    }
	
			case Node.CDATA_SECTION_NODE: 
			case Node.TEXT_NODE: {
				sb.append(node.getNodeValue().trim());
				break;
			}
		}
		
		return sb.toString();
	}

}
