/*
   Copyright 2005 Julian Robichaux

   Licensed under the Academic Free License version 2.1 (the "License");
   you may not use this file except in compliance with the License.
   You may obtain a copy of the License at

       http://opensource.org/licenses/afl-2.1.php

   Except as expressly stated in the License, software distributed 
   under the License is distributed on an "AS IS" BASIS, and WITHOUT 
   WARRANTY, either express or implied. See the License for the specific 
   language governing permissions and limitations under the License.

 */

package com.nsftools.jurst;

import org.apache.soap.rpc.SOAPContext;
import org.apache.soap.util.Bean;
import org.apache.soap.util.xml.Deserializer;
import org.apache.soap.util.xml.QName;
import org.apache.soap.util.xml.XMLJavaMappingRegistry;
import org.w3c.dom.Node;

/**
 * XmlNodeDeserializer is an extremely simple deserializer
 * (org.apache.soap.util.xml.Deserializer) that just 
 * returns the Node (org.w3c.dom.Node) that was used as a 
 * response parameter to a SOAP message.
 * <p>
 * You can use this when you don't know what the response will look like,
 * or when the response is a complex data type that you don't feel
 * like modeling with a Bean and handling with a BeanSerializer.
 * XmlNodeDeserializer allows you to take the response parameter and
 * parse it yourself as a regular XML DOM Node.
 * 
 * @author Julian Robichaux
 * @version 0.9.2
 */
public class XmlNodeDeserializer implements Deserializer {

	public Bean unmarshall (String inScopeEncStyle, QName elementType,
			Node src, XMLJavaMappingRegistry xjmr,
			SOAPContext ctx)
			throws IllegalArgumentException {
		return new Bean(Node.class, src);
	}

}
